==========
Developers
==========

* Flavio C. Coelho <fccoelho@gmail.com>
* Renato R. Souza <rsouza.fgv@gmail.com>

FGV's Python summer course class of 2017
----------------------------------------
- Alifer Sales <alifer10@gmail.com>
- Amanda Maria <amanda.scupinari@gmail.com>
- Brenda Prallon <brendaprallonn@gmail.com>
- Bruno Resende <bcmresende@gmail.com>
- Bruno Cuconato <bclaro@gmail.com>
- Diego B. Batalha <db_batalha_@hotmail.com>
- Fernanda Scovino <fscovino@gmail.com>
- Gabriel Jardim <g.jardimpp@gmail.com>
- Guilherme W. Barros <wangbarros@gmail.com>
- João Carabetta (joao.carabetta@gmail.com>
- Lucas Branco <lucaslopesbranco@gmail.com>
- Lucas Meireles <lucas.meireles.ta@gmail.com>
- Rafael Mesquita <rafaelsmesquita1997@gmail.com>
- Thiago Trabach <thiago.trabach@gmail.com>
- Jorge F. P. Gimenez <jf.gimenez@hotmail.com>
